@@ -22,28 +22,28 @@ Plot.PCA <- function(PC, Titles = NA, xlabel = NA, ylabel = NA,
   if (!is.character(Titles[2]) || is.na(Titles[2])) Titles[2] = c("Grafico correspondente as linhas (observacoes)")
   if (!is.character(Titles[3]) || is.na(Titles[3])) Titles[3] = c("Grafico correspondente as colunas (variaveis)")
   
-  if (!is.character(xlabel) && !is.na(xlabel))
+  if (!is.character(xlabel) && !is.na(xlabel[1]))
      stop("Entrada para 'xlabel' esta incorreta, deve ser do tipo caracter ou string. Verifique!")
   
-  if (!is.character(ylabel) && !is.na(ylabel))
+  if (!is.character(ylabel) && !is.na(ylabel[1]))
      stop("Entrada para 'ylabel' esta incorreta, deve ser do tipo caracter ou string. Verifique!")
   
   if (!is.logical(Color))
      stop("Entrada para 'Color' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
   
-  if (!is.na(LinLab) && length(LinLab)!=nrow(PC$MatrixEsc))
+  if (!is.na(LinLab[1]) && length(LinLab)!=nrow(PC$MatrixEsc))
      stop("O numero elementos do rotulo para linhas 'LinLab' difere do numero de linhas da base de dados. Verifique!")
   
   if (!is.logical(Casc))
      stop("Entrada para 'Casc' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
   
-  if (is.na(LinLab))
+  if (is.na(LinLab[1]))
      LinLab <- rownames(PC$MatrixEsc)
   
-  if (is.na(xlabel))
+  if (is.na(xlabel[1]))
      xlabel = paste("Primeira coordenada (",round(PC$MatrixAutoVlr[1,2],2),"%)",sep="")
   
-  if (is.na(ylabel))
+  if (is.na(ylabel[1]))
      ylabel = paste("Segunda coordenada (",round(PC$MatrixAutoVlr[2,2],2),"%)",sep="")
   #####   FIM - Informacoes usadas nos Graficos  #####
   
